@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed.c 7065 2007-06-03 22:11:05Z chpe $
+ *  $Id: ephy-embed.c 7227 2007-07-31 03:48:08Z diegoe $
  */
 
 #include "config.h"
@@ -24,8 +24,6 @@
 
 #include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
-#include "mozilla-embed-single.h"
-#include "mozilla-embed.h"
 
 static void ephy_embed_base_init (gpointer g_class);
 
@@ -293,7 +291,7 @@ ephy_embed_base_init (gpointer g_class)
  * @uri: URI of the new content
  *
  * The ::ge_content_change signal is emitted when a new page content
- * is being loadedinto the browser. It's a good place to do view
+ * is being loaded into the browser. It's a good place to do view
  * related changes, for example to restore the zoom level of a page
  * or to set an user style sheet.
  **/
