@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 7014 2007-04-24 19:45:19Z diegoe $
+ *  $Id: popup-commands.c 7167 2007-07-16 15:30:51Z chpe $
  */
 
 #include "config.h"
@@ -272,7 +272,7 @@ popup_cmd_save_image_as (GtkAction *action,
 			   window, TRUE, "image");
 }
 
-#define GNOME_BACKGROUND_PREFERENCES "gnome-background-properties"
+#define GNOME_APPEARANCE_PROPERTIES  "gnome-appearance-properties.desktop"
 
 static void
 background_download_completed (EphyEmbedPersist *persist)
@@ -284,16 +284,20 @@ background_download_completed (EphyEmbedPersist *persist)
 
 	bg = ephy_embed_persist_get_dest (persist);
 
-	g_object_unref (persist);
-
-	/* open the "Background Properties" capplet */
-	if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+	/* open the Appearance Properties capplet on the Background tab */
+	if (!ephy_file_launch_desktop_file (GNOME_APPEARANCE_PROPERTIES, bg, user_time))
 	{
-		/* If the above try didn't work, then we try the Fedora name.
-		 * This is a fix for #387206, but is actually a workaround for
-		 * bugzilla.redhat.com #201867 */
-		ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+		/* Fallback for <= 2.18 desktop: try to open the "Background Properties" capplet */
+		if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+		{
+			/* If the above try didn't work, then we try the Fedora name.
+			 * This is a fix for #387206, but is actually a workaround for
+			 * bugzilla.redhat.com #201867 */
+			ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+		}
 	}
+
+	g_object_unref (persist);
 }
 
 void
